{ config,
  pkgs,
  ... }:

let
  gitpkgs = import <gitpkgs> {};
in
{
  nixpkgs.config = {
    allowBroken = false;

    packageOverrides = pkgs: rec {
      go = gitpkgs.go1_6;
      bluez = pkgs.bluez5;

      myLinuxPackages = pkgs.recurseIntoAttrs (pkgs.linuxPackagesFor
        (pkgs.linux_latest.override {
        kernelPatches = pkgs.linux_latest.kernelPatches ++ [
          {
            name = "bfq1";
            patch = pkgs.fetchurl {
              url = "ftp://teambelgium.net/bfq/patches/4.5.0-v7r11/0001-block-cgroups-kconfig-build-bits-for-BFQ-v7r11-4.5.0.patch";
              sha256 = "1j6h831kj32c9slzm4vhjvd8m17gbwh713kcpc54z9i02fwyq6ax";
            };
          }
          {
            name = "bfq2";
            patch = pkgs.fetchurl {
              url = "ftp://teambelgium.net/bfq/patches/4.5.0-v7r11/0002-block-introduce-the-BFQ-v7r11-I-O-sched-for-4.5.0.patch";
              sha256 = "1q8nf7fcp72s2xz2pfl22sv4w5fm4hzgciljrkd3g7gj5xvi27lw";
            };
          }
          {
            name = "bfq3";
            patch = pkgs.fetchurl {
              url = "ftp://teambelgium.net/bfq/patches/4.5.0-v7r11/0003-block-bfq-add-Early-Queue-Merge-EQM-to-BFQ-v7r11-for.patch";
              sha256 = "1q2j7g3cfwi52psxgwa06hadl6c2fh87ckm07pyaj35n6524gjg0";
            };
          }
        ];
        extraConfig  = ''
          BFQ_GROUP_IOSCHED y
          IOSCHED_BFQ y
          DEFAULT_BFQ y
        '';
        })
        pkgs.linuxPackages_latest
      );
    };

    allowUnfree = true;

    chromium = {
      enablePepperFlash = true;
      enablePepperPDF = true;
    };

    firefox = {
      enableGoogleTalkPlugin = true;
      enableAdobeFlash = false;
    };

    pidgin = {
      openssl = true;
      gnutls = true;
    };

    keepass = pkgs.keepass.override {
      plugins = [ pkgs.keepass-keefox ];
    };

# TODO: implement support for this
#    libvirt = {
#      xenSupport = false;
#    };

  };

  imports =
    [
      ../common/pkg/default.nix
      ../common/pkg/neovim.nix
    ];

  environment.systemPackages = with pkgs; [
    androidsdk_4_4

    nixops
    nox
    ansible

    gnupg
    picocom
    xfce.terminal
    xorg.xbacklight
    coreutils
    lsof

    xscreensaver
    firefox-wrapper
    chromium
    seafile-client

    qpdfview
    thunderbird
    pidgin
    hexchat
    keepass
    skype

    teamviewer
    x11_ssh_askpass
    gnome3.dconf # needed by virtmanager
    virtmanager

    vlc
    audacity
    pavucontrol
    spotify

    gimp
    inkscape
    pdftk
    imagemagick

    iptables
    nftables
    iperf

    #pandoc
    pythonFull
  ] ++ [
    gitpkgs.rkt
    gitpkgs.flannel
    gitpkgs.remmina
  ];
}
